@@ -2,10 +2,11 @@
 """main file getBitMEXData.py."""
 from time import sleep
 from typing import Tuple
+
 import argparse
 import logging
 import os
-import platform # handle os check
+import platform  # handle os check
 import time
 import sys
 import requests as rq
@@ -15,18 +16,21 @@ from pathlib import Path
 from getBitMEXData.getBitMEXtypes import bucketT, oTimestampT, symbolT
 from getBitMEXData.settings import LIVE_URL, TEST_URL, TC, STARTDATE_DFT
 
+# setting the default time zone for the system
 if platform.system() == "Linux":
     # Time.tzset ne fonctionne qu'avec UNIX le mettre en commentaire pour windows
     # mais veillé à spécifier la date de départ et de fin des messages.  avec les option --startTime et --endTime
-    os.environ["TZ"] = "UTC"
-    time.tzset()
+    OS_TZ = os.environ.get("TZ", "UTC")
+else:
+    # in the case os.environ does not exist
+    OZ_TZ = "UTC"
+
+STRF = "%Y-%m-%d__%H_%M"  # default time format for saving the data
 
 
 logger = logging.getLogger()
 logger.setLevel("INFO")
 
-STRF = "%Y-%m-%dT%H:%M"  # default time format for saving the data
-
 # Converts bitmex time unit to pd.timestamp time units
 URLS = {
     True: LIVE_URL,
@@ -131,13 +135,13 @@ def get_bucketed_trades(
     auth = None  # auth = APIKeyAuthWithExpires(apiKey, apiSecret)
     sess = init_session()
     fout = (
-        "./btxData-{binSize}-{endTime.strftime('%Y%m%dT%H_%M')}.csv"
+        "./btxData-{binSize}-{endTime.strftime(STRF)}.csv"
         if fout is None
         else fout
     )
     # prise en compte de windows
     fout = Path(fout)
-    
+
     Q = (
         {
             "binSize": binSize,
@@ -231,12 +235,12 @@ def reached(lastReqDate, endTime=None):
     Returns True si endTime <= lastReqDate (end more recent than last)
     or if endTime is None
     """
-    # Check the tz settings
-    endTz = os.environ["TZ"] if endTime.tz is None else None
-    lastTz = os.environ["TZ"] if lastReqDate.tz is None else None
-    return endTime is None or Timestamp(endTime, tz=endTz) <= Timestamp(
-        lastReqDate, tz=lastTz
-    )
+    endTz = OS_TZ if endTime is None or endTime.tz is None else endTime.tz
+    lastTz = OS_TZ if lastReqDate.tz is None else lastReqDate.tz
+
+    return endTime is None or Timestamp(endTime).tz_localize(endTz) <= Timestamp(
+        lastReqDate
+    ).tz_convert(lastTz)
 
 
 def parse_args():
@@ -293,12 +297,19 @@ def main_prg():
         if args.startTime is None
         else Timestamp(args.startTime)
     )
-    # To avoir empty request we stop one unit befor the present date.
+    # localising the timezone
+    startTime = starTime.tz_localize(OS_TZ)
+
+    # To avoid empty request we stop one unit befor the present date.
     endTime = (
         (Timestamp.now() - Timedelta(nUnit, tUnit)).round(timeUnit)
         if args.endTime is None
         else Timestamp(args.endTime)
     )
+
+    # making_sure the format is also valid for windows
+    endTime = endTime.tz_localize(OS_TZ).strftime(STRF)
+
     query = {
         "binSize": args.binSize,
         "count": args.count,
@@ -306,11 +317,13 @@ def main_prg():
         "reverse": "false",
         "symbol": args.symbol,
     }
+
+    # kwargs stand for key words arguments
     kwargs = {
-        "endTime": endTime,
+        "endTime": endTime
         "fout": f"{args.fout}{args.symbol}-{args.binSize}-{endTime}",
         "pause": args.pause,
-        "startTime": startTime,
+        "startTime": starTime
     }
 
     # use live or test ids
